==> cgal-3.1.tbz: include/CGAL/Triangulation_short_names_2.h <==
// Copyright (c) 1997  INRIA Sophia-Antipolis (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you may redistribute it under
// the terms of the Q Public License version 1.0.
// See the file LICENSE.QPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $Source: /CVSROOT/CGAL/Packages/Triangulation_2/include/CGAL/Triangulation_short_names_2.h,v $
// $Revision: 1.17 $ $Date: 2004/04/26 08:49:50 $
// $Name:  $
//
// Author(s)     : Mariette Yvinec

#ifndef CGAL_TRIANGULATION_SHORT_NAMES_2_H
#define CGAL_TRIANGULATION_SHORT_NAMES_2_H


//Define shorter names to please linker (g++/egcs)


#define Triangulation_data_structure_2 Tds2
#define Triangulation_vertex_base_2  Tvb
#define Triangulation_face_base_2  Tfb
#define Triangulation_euclidean_traits_2 Et2
#define Triangulation_euclidean_traits_xy_3 Etxy3
#define Triangulation_euclidean_traits_xz_3 Etxz3
#define Triangulation_euclidean_traits_yz_3 Etyz3

#define Triangulation_ds_vertex_2             Tdsv
#define Triangulation_ds_face_2               Tdsf
#define Triangulation_ds_face_base_2          Tdsfb
#define Triangulation_ds_vertex_base_2        Tdsvb
#define Triangulation_vertex_2                Tv
#define Triangulation_face_2                  Tf
#define Triangulation_vertex_handle_2         Tvh
#define Triangulation_face_handle_2           Tfh
#define Triangulation_vertex_iterator_2       Tvi
#define Triangulation_face_iterator_2         Tfi
#define Triangulation_edge_iterator_2         Tei
#define Triangulation_all_faces_iterator_2    Tafi
#define Triangulation_all_edges_iterator_2    Taei
#define Triangulation_all_vertices_iterator_2 Tavi
#define Triangulation_finite_faces_iterator_2 Tffi
#define Triangulation_finite_edges_iterator_2 Tfei
#define Triangulation_finite_vertices_iterator_2 Tfvi
#define Triangulation_vertex_circulator_2     Tvc
#define Triangulation_face_circulator_2       Tfc
#define Triangulation_edge_circulator_2       Tec

#define Constrained_triangulation_face_base_2    Ctfb
#define Regular_triangulation_euclidean_traits_2 Rtet2
#define Regular_triangulation_face_base_2        Rtfb
#define Regular_triangulation_vertex_base_2      Rtvb

#endif //CGAL_TRIANGULATION_SHORT_NAMES_2_H

==> cgal-3.4_1.tbz: include/CGAL/Triangulation_short_names_2.h <==
// Copyright (c) 1997  INRIA Sophia-Antipolis (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you may redistribute it under
// the terms of the Q Public License version 1.0.
// See the file LICENSE.QPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Triangulation_2/include/CGAL/Triangulation_short_names_2.h $
// $Id: Triangulation_short_names_2.h 41378 2007-12-30 23:54:19Z spion $
// 
//
// Author(s)     : Mariette Yvinec

#ifndef CGAL_TRIANGULATION_SHORT_NAMES_2_H
#define CGAL_TRIANGULATION_SHORT_NAMES_2_H

#if 0 // Disabled to see if it's still really needed.

//Define shorter names to please some linkers

#define Triangulation_data_structure_2 Tds2
#define Triangulation_vertex_base_2  Tvb
#define Triangulation_face_base_2  Tfb
#define Triangulation_euclidean_traits_2 Et2
#define Triangulation_euclidean_traits_xy_3 Etxy3
#define Triangulation_euclidean_traits_xz_3 Etxz3
#define Triangulation_euclidean_traits_yz_3 Etyz3

#define Triangulation_ds_vertex_2             Tdsv
#define Triangulation_ds_face_2               Tdsf
#define Triangulation_ds_face_base_2          Tdsfb
#define Triangulation_ds_vertex_base_2        Tdsvb
#define Triangulation_vertex_2                Tv
#define Triangulation_face_2                  Tf
#define Triangulation_vertex_handle_2         Tvh
#define Triangulation_face_handle_2           Tfh
#define Triangulation_vertex_iterator_2       Tvi
#define Triangulation_face_iterator_2         Tfi
#define Triangulation_edge_iterator_2         Tei
#define Triangulation_all_faces_iterator_2    Tafi
#define Triangulation_all_edges_iterator_2    Taei
#define Triangulation_all_vertices_iterator_2 Tavi
#define Triangulation_finite_faces_iterator_2 Tffi
#define Triangulation_finite_edges_iterator_2 Tfei
#define Triangulation_finite_vertices_iterator_2 Tfvi
#define Triangulation_vertex_circulator_2     Tvc
#define Triangulation_face_circulator_2       Tfc
#define Triangulation_edge_circulator_2       Tec

#define Constrained_triangulation_face_base_2    Ctfb
#define Regular_triangulation_euclidean_traits_2 Rtet2
#define Regular_triangulation_face_base_2        Rtfb
#define Regular_triangulation_vertex_base_2      Rtvb

#endif // 0

#endif //CGAL_TRIANGULATION_SHORT_NAMES_2_H
